@@ -508,8 +508,8 @@ packageMap = {
     "OutageSchedule": "CIM15.IEC61970.Outage",
     "ClearanceTagType": "CIM15.IEC61970.Outage",
     "ClearanceTag": "CIM15.IEC61970.Outage",
-    "Cut": "CIM15.IEC61970.Cuts and jumpers",
-    "Clamp": "CIM15.IEC61970.Cuts and jumpers",
+    "Cut": "CIM15.IEC61970.CutsJumpers",
+    "Clamp": "CIM15.IEC61970.CutsJumpers",
     "RecloseSequence": "CIM15.IEC61970.Protection",
     "SynchrocheckRelay": "CIM15.IEC61970.Protection",
     "CurrentRelay": "CIM15.IEC61970.Protection",
